@@ -35,6 +35,7 @@ pub enum KeyType {
     Set = REDISMODULE_KEYTYPE_SET,
     ZSet = REDISMODULE_KEYTYPE_ZSET,
     Module = REDISMODULE_KEYTYPE_MODULE,
+    Stream = REDISMODULE_KEYTYPE_STREAM,
 }
 
 impl From<c_int> for KeyType {
@@ -105,6 +106,7 @@ bitflags! {
         const EVICTED = REDISMODULE_NOTIFY_EVICTED;
         const STREAM = REDISMODULE_NOTIFY_STREAM;
         const MODULE = REDISMODULE_NOTIFY_MODULE;
+        const LOADED = REDISMODULE_NOTIFY_LOADED;
         const ALL = REDISMODULE_NOTIFY_ALL;
     }
 }
